### 2.38.0 (25.10.2022)

- Исправлен url для очистки кеша
- Исправлено кеширование url

### 2.38.0-rc7 (14.10.2022)

- В админ.панель и тулбар шаблонов добавлена кнопка очистки кеша
- В редиректах с `{url}////..` на `{url}` исправлена ошибка с потерей квери параметров
- Исправлена проблема с url api
- Исправлена проблема с поддержкой языков с `-` в коде

### 2.38.0-rc5 - 2.38.0-rc6 (14.10.2022)

- Исправлены тесты (добавлена проверка на то, что страница не возвращает 404)

### 2.38.0-rc4  (12.10.2022)

- Добавлены редиректы с `{url}////..` на `{url}`.
- Исправлена ошибка с шаблоном компонента `Grapesjs`.

### 2.38.0-rc2 - 2.38.0-rc3  (12.10.2022)

- Добавлена возможность настраивать список ключей для шаблонов сео-тегов (смотрите `Readme.md`).

### 2.38.0-rc1 (10.10.2022)

- Добавлена возможность создания шаблонов для seo-тегов (смотрите `Readme.md`).
- Добавлен компонент `Grapesjs`
- Разделены контексты компонентов на шаблонные и для api (`get_context_data` и `get_api_context_data` соответственно)

### 2.37.0 (07.10.2022)

- Добавлена модель `GarpixPageSiteConfiguration` - настройки, используемые в модуле

### 2.36.1 (06.10.2022)

- Добавлен templatetag `gx_component` (добавляет блоку с компонентом возможность редактирования для пользователя со статусом персонала)

### 2.36.0 (30.09.2022)

- Изменен порядок отображения названий страниц и компонентов при добавлении в админ.панели
- Добавлена возможность редактировать компонент из шаблона для админа (смотрите `Readme.md`)
- В контекст страницы добавлены конексты компонентов (ключ `components`)

### 2.35.0 (20.09.2022)

- Добавлена зависимость garpix-admin-lock.

### 2.34.1 (20.09.2022)

- Исправлена ошибка c инвалидацией кэша страниц.

### 2.34.0 (01.09.2022)

- Переделана логика получения страницы по url

### 2.33.1 (01.09.2022)

- Поправлен баг с формированием url

### 2.33.0 (01.09.2022)

- Исправлена ошибка в кэшировании страниц.

### 2.32.0 (30.08.2022)

- Добавлена возможность клонировать компонент и страницу в адмиин-панели из деталки и из списка. Создается полная копия, со всеми связанными сущностями
- В seo-тег `<link rel="canonical">` прокинут полный путь к странице

### 2.31.0 (26.08.2022)

- Кнопка "Сохранить" на странице создания компонента теперь отображается сверху страницы и у выбранного типа компонента.
- При добавлении компонента из страницы, теперь нельзя выбирать страницы для отображения.

### 2.30.0 (25.08.2022)

- Добавлен clone_object action для компонентов
- Изменена валидация ЧПУ страницы. Теперь проверяется уникальность полного url, с учетом сайтов и родителей.

### 2.29.0 (19.08.2022)

- Добавлена возможность группировки компонентов по группе
- Добавлена возможность добавлять больше одного превью для компонента
- Добавлена возможность фильтрации компонентов по названию
- При клике на превью компонента радио-кнопка отмечается активной

### 2.28.2 (18.08.2022)

- Неактивные страницы больше не открываются.

### 2.28.1 (18.08.2022)

- Поправлены критические ошибки,
- Тесты с несколькими языками теперь проходят.
- Временно отключили кэширование URL

### 2.28.0 (16.08.2022)

- Исправлена 500 ошибка в админке при битых страницах и компонентах
- Доработана обработка поля query_parameters_required у страниц для шаблонов

### 2.27.1 (25.07.2022)

- Добавлен request в контекст

### 2.27.0 (25.07.2022)

- Добавлено превью при создании компонента

### 2.26.0 (01.07.2022)

- Добавлен контейнер redis
- Добавлена библиотека django-redis
- Добавлено кэширование пути и контекста компонент + инвалидация

### 2.25.0 (29.06.2022)

- Добавлен класс GarpixPagePagination для удобной drf пагинации внутри контекстов страниц (пример в `Readme.md` и в `ListPage`)
- В `BaseListPage` добавлен `paginated_children_list` - пагинированный список дочерних страниц для drf
- Добавлены шаблоны в компоненты

### 2.24.0 (06.05.2022)

- Добавлена возможность сделать компонент неактивным
- Исправлена сортировка компонентов в api
- Добавлены page_model в ответах на 401, 403, 404 в api

### 2.23.0 (25.04.2022)

- Исправлен action clone_object в админке

### 2.22.0 (22.04.2022)

- Добавлен дополнительный менеджер `GPolymorphicCurrentSiteManager` (`BasePage.polymorphic_on_site.all()`)

### 2.21.0 (15.04.2022)

- В api добавлен эндпоинт на получение списка моделей страниц (по умолчанию `api/page_models_list/`)

### 2.20.0 (12.04.2022)

- Добавлена возможность добавлять компоненты страниц.

### 2.19.0 (18.03.2022)

- Исправлен баг сериализации модели страницы.

### 2.18.0 (17.03.2022)

- Исправлена ошибка с инлайнами в табах (не отображались).

### 2.17.0 (22.02.2022)

- Исправлены автотесты страниц (выводится ЧПУ и модель в ответах)
- Добавлена возможность задать поведение страниц, требующих квери параметры для загрузки

### 2.16.0 (18.02.2022)

- Обновлена зависимость `django-polymorphic-tree-for-garpix-page==2.1.1`.

### 2.15.0 (17.02.2022)

- Добавлена поддержка RichTextField, RichTextUploadingField, PhoneNumberField при тестировании страниц.
- Исправлена ошибка с мультиязычностью страниц.

### 2.14.0 (16.02.2022)

- Исправлена ошибка с выбором языка по API.
- Исправлена ошибка с получением страниц по API с '/' вконце.
- Добавлены юнит-тесты на получение страниц по API с разными языковыми кодами, с '/' вконце, индексной страницы.
- Добавлена проверка корректности ЧПУ.
- В админку редактирования страницы добавлен полный ЧПУ.

### 2.13.0 (02.02.2022)

- Добавлены юнит-тесты, проверяющие страницы на корректные статусы. Используйте `python3 manage.py qa` для проверки.
- Добавлена возможность закрыть страницу правами. Переопределяйте `login_required` и `permission` модели `BasePage` (примеры в `README.md`).
- Глобальный контекст в api теперь возвращается при статусах 401, 403, 404.
- SEO теги в админке вынесены в отдельный таб.
- Исправлена ошибка при пагинации в структуре.

### 2.12.0 (26.09.2021)

- Исправлена ошибка с выбором языка при get_absolute_url при обращении по API.
- Изменен вывод переменных по пагинации для API.

### 2.11.0 (25.09.2021)

- Убраны внезапно выскакивающие разделы страниц. Оставлена только Структура страниц.
- Добавлен фильтр по типу страницы в Структуру страниц.
- Добавлено поле Тип в Структуру страниц при выводе списка.
- Добавлен фильтр по Сайтам в Структуру страниц.

### 2.10.0 (19.09.2021)

- Добавлен глобальный контекст для Page Api, задается так `GARPIX_PAGE_GLOBAL_CONTEXT = 'garpix_page.contexts.global_context.global_context'` и сама функция:
```python
def global_context(request, page):
    return {}
```

### 2.9.0 (14.09.2021)

- Использован `GarpixPaginator` из `garpix_utils` - позволяет выводить более красивую пагинацию. Изменен также шаблон для пагинации.

### 2.8.0 (10.09.2021)

- В кодогенерации сделана проверка на существующие строки в `__init__.py` файлах.
- Добавлен `breadcrumb.html`.
- При кодогенерации изменено содержимое шаблонов - подставляется согласно выбранному параметру `--base`.

### 2.7.0 (09.09.2021)

- Добавлен пакет `garpix_package`.
- Добавлена кодогенерация:
```bash
# Для обычных страниц
python3 backend/manage.py startpage --app=myapp --page=my --base=page

# Для списочных страниц
python3 backend/manage.py startpage --app=myapp --page=my_list --base=list

# Для поисковой страницы
python3 backend/manage.py startpage --app=myapp --page=search --base=search
```

### 2.6.0 (08.09.2021)

- Теперь нет ошибки при развертывании свежего проекта, т.к. добавлена индексная страница со ссылками
на документацию (только если нет главной страницы).
- Исправлены ошибки после линтинга кода.
- По умолчанию, при создании страниц, выбраны все сайты (`Site.objects.all()`) в административной панели.
- Добавлена базовая модель `BaseListPage`, которую можно использовать для списочных страниц (т.е. у которых есть дочерние страницы).
- Добавлена вьюшка `sitemap_view` для карты сайта `/sitemap.xml`

### 2.5.0 (06.08.2021)

- Added method get_serializer() in BasePage.

### 2.4.0 (03.08.2021)

- Set to page `title` BasePage `title`, if `seo_title` is not defined.

### 2.3.0 (03.08.2021)

- Added list_per_page to BasePageAdmin.

### 2.2.0 (23.06.2021)

- Added page_api urls for SPA sites.

### 2.1.0 (22.06.2021)

- Added admin-toolbar for staffs, use `{% include 'garpix_page/admin_toolbar.html' %}` in templates.

### 2.0.1 (22.06.2021)

- Fix bug with another home pages models.

### 2.0.0 (21.06.2021)

- Removed contexts and useless dicts from `settings.py`. All in models!

### 1.0.0 (11.03.2021)

- First release in pypi.org.
